@@ -1,3 +1,4 @@
+import enum
 from copy import deepcopy
 from inspect import isawaitable
 from typing import Any, Callable, Dict, Optional
@@ -19,32 +20,27 @@ DATETIME_FORMAT = "%Y-%m-%dT%H:%M:%S.%fZ"
 ArgFilter = Callable[[Dict[str, Any], GraphQLResolveInfo], Dict[str, Any]]
 
 
-if hasattr(trace, "use_span"):
-
-    def _use_span(span: Span, tracer: Tracer):
-        return trace.use_span(span)
-
-
-else:
-
-    def _use_span(span: Span, tracer: Tracer):
-        return tracer.use_span(span)
+class RequestStage(enum.Enum):
+    REQUEST = enum.auto()
+    PARSING = enum.auto()
+    VALIDATION = enum.auto()
 
 
 class OpenTelemetryExtension(Extension):
     _arg_filter: Optional[ArgFilter]
-    _root_span: Span
+    _span_holder: Dict[str, Span] = dict()
     _tracer: Tracer
 
     def __init__(
         self,
         *,
-        execution_context: ExecutionContext,
+        execution_context: Optional[ExecutionContext] = None,
         arg_filter: Optional[ArgFilter] = None,
     ):
         self._arg_filter = arg_filter
         self._tracer = trace.get_tracer("strawberry")
-        self.execution_context = execution_context
+        if execution_context:
+            self.execution_context = execution_context
 
     def on_request_start(self):
         span_name = (
@@ -53,12 +49,35 @@ class OpenTelemetryExtension(Extension):
             else "GraphQL Query"
         )
 
-        self._root_span = self._tracer.start_span(span_name, kind=SpanKind.SERVER)
-        self._root_span.set_attribute("component", "graphql")
-        self._root_span.set_attribute("query", self.execution_context.query)
+        self._span_holder[RequestStage.REQUEST] = self._tracer.start_span(
+            span_name, kind=SpanKind.SERVER
+        )
+        self._span_holder[RequestStage.REQUEST].set_attribute("component", "graphql")
+        self._span_holder[RequestStage.REQUEST].set_attribute(
+            "query", self.execution_context.query
+        )
 
     def on_request_end(self):
-        self._root_span.end()
+        self._span_holder[RequestStage.REQUEST].end()
+
+    def on_validation_start(self):
+        ctx = trace.set_span_in_context(self._span_holder[RequestStage.REQUEST])
+        self._span_holder[RequestStage.VALIDATION] = self._tracer.start_span(
+            "GraphQL Validation",
+            context=ctx,
+        )
+
+    def on_validation_end(self):
+        self._span_holder[RequestStage.VALIDATION].end()
+
+    def on_parsing_start(self):
+        ctx = trace.set_span_in_context(self._span_holder[RequestStage.REQUEST])
+        self._span_holder[RequestStage.PARSING] = self._tracer.start_span(
+            "GraphQL Parsing", context=ctx
+        )
+
+    def on_parsing_end(self):
+        self._span_holder[RequestStage.PARSING].end()
 
     def filter_resolver_args(
         self, args: Dict[str, Any], info: GraphQLResolveInfo
@@ -89,15 +108,17 @@ class OpenTelemetryExtension(Extension):
 
             return result
 
-        with _use_span(self._root_span, self._tracer):
-            with self._tracer.start_span(info.field_name, kind=SpanKind.SERVER) as span:
-                self.add_tags(span, info, kwargs)
-                result = _next(root, info, *args, **kwargs)
+        with self._tracer.start_as_current_span(
+            f"GraphQL Resolving: {info.field_name}",
+            context=trace.set_span_in_context(self._span_holder[RequestStage.REQUEST]),
+        ) as span:
+            self.add_tags(span, info, kwargs)
+            result = _next(root, info, *args, **kwargs)
 
-                if isawaitable(result):
-                    result = await result
+            if isawaitable(result):
+                result = await result
 
-                return result
+            return result
 
 
 class OpenTelemetryExtensionSync(OpenTelemetryExtension):
@@ -107,9 +128,11 @@ class OpenTelemetryExtensionSync(OpenTelemetryExtension):
 
             return result
 
-        with _use_span(self._root_span, self._tracer):
-            with self._tracer.start_span(info.field_name, kind=SpanKind.SERVER) as span:
-                self.add_tags(span, info, kwargs)
-                result = _next(root, info, *args, **kwargs)
+        with self._tracer.start_as_current_span(
+            "GraphQL Resolving: {info.field_name}",
+            context=trace.set_span_in_context(self._span_holder[RequestStage.REQUEST]),
+        ) as span:
+            self.add_tags(span, info, kwargs)
+            result = _next(root, info, *args, **kwargs)
 
-                return result
+            return result
