@@ -1,4 +1,6 @@
-from typing import Callable, List, Optional, Type, Union, cast
+from typing import Any, Callable, List, Optional, Type, TypeVar, Union, cast, overload
+
+from typing_extensions import Literal
 
 from graphql import (
     GraphQLField,
@@ -11,6 +13,7 @@ from graphql import (
 )
 from graphql.type.definition import GraphQLArgument
 
+from strawberry.arguments import UNSET
 from strawberry.custom_scalar import ScalarDefinition
 from strawberry.enum import EnumDefinition
 from strawberry.permission import BasePermission
@@ -19,45 +22,104 @@ from strawberry.types.types import TypeDefinition
 from strawberry.union import StrawberryUnion
 from strawberry.utils.inspect import get_func_args
 
-from .field import FederationFieldParams, field as base_field
+from .field import (
+    _RESOLVER_TYPE,
+    FederationFieldParams,
+    StrawberryField,
+    field as base_field,
+)
 from .object_type import FederationTypeParams, type as base_type
 from .printer import print_schema
 from .schema import Schema as BaseSchema
+from .utils.typing import __dataclass_transform__
 
 
-def type(
-    cls: Type = None,
-    *,
-    name: str = None,
-    description: str = None,
-    keys: List[str] = None,
-    extend: bool = False
-):
-    return base_type(
-        cls,
-        name=name,
-        description=description,
-        federation=FederationTypeParams(keys=keys or [], extend=extend),
-    )
+T = TypeVar("T")
 
 
+@overload
 def field(
-    resolver: Optional[Callable] = None,
     *,
+    resolver: Callable[[], T],
     name: Optional[str] = None,
+    is_subscription: bool = False,
+    description: Optional[str] = None,
     provides: Optional[List[str]] = None,
     requires: Optional[List[str]] = None,
     external: bool = False,
+    init: Literal[False] = False,
+    permission_classes: Optional[List[Type[BasePermission]]] = None,
+    deprecation_reason: Optional[str] = None,
+    default: Any = UNSET,
+    default_factory: Union[Callable, object] = UNSET,
+) -> T:
+    ...
+
+
+@overload
+def field(
+    *,
+    name: Optional[str] = None,
     is_subscription: bool = False,
     description: Optional[str] = None,
-    permission_classes: Optional[List[Type[BasePermission]]] = None
-):
+    provides: Optional[List[str]] = None,
+    requires: Optional[List[str]] = None,
+    external: bool = False,
+    init: Literal[True] = True,
+    permission_classes: Optional[List[Type[BasePermission]]] = None,
+    deprecation_reason: Optional[str] = None,
+    default: Any = UNSET,
+    default_factory: Union[Callable, object] = UNSET,
+) -> Any:
+    ...
+
+
+@overload
+def field(
+    resolver: _RESOLVER_TYPE,
+    *,
+    name: Optional[str] = None,
+    is_subscription: bool = False,
+    description: Optional[str] = None,
+    provides: Optional[List[str]] = None,
+    requires: Optional[List[str]] = None,
+    external: bool = False,
+    permission_classes: Optional[List[Type[BasePermission]]] = None,
+    deprecation_reason: Optional[str] = None,
+    default: Any = UNSET,
+    default_factory: Union[Callable, object] = UNSET,
+) -> StrawberryField:
+    ...
+
+
+def field(
+    resolver=None,
+    *,
+    name=None,
+    is_subscription=False,
+    description=None,
+    provides=None,
+    requires=None,
+    external=False,
+    permission_classes=None,
+    deprecation_reason=None,
+    default=UNSET,
+    default_factory=UNSET,
+    # This init parameter is used by PyRight to determine whether this field
+    # is added in the constructor or not. It is not used to change
+    # any behavior at the moment.
+    init=None,
+) -> Any:
     return base_field(
         resolver=resolver,
         name=name,
         is_subscription=is_subscription,
         description=description,
         permission_classes=permission_classes,
+        deprecation_reason=deprecation_reason,
+        default=default,
+        default_factory=default_factory,
+        init=init,
         federation=FederationFieldParams(
             provides=provides or [], requires=requires or [], external=external
         ),
@@ -100,6 +162,25 @@ def _get_entity_type(type_map: TypeMap):
     return entity_type
 
 
+@__dataclass_transform__(
+    order_default=True, field_descriptors=(base_field, field, StrawberryField)
+)
+def type(
+    cls: Type = None,
+    *,
+    name: str = None,
+    description: str = None,
+    keys: List[str] = None,
+    extend: bool = False,
+):
+    return base_type(
+        cls,
+        name=name,
+        description=description,
+        federation=FederationTypeParams(keys=keys or [], extend=extend),
+    )
+
+
 class Schema(BaseSchema):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
